==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerinstance/kotlin/inputs/GpuResourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerinstance.kotlin.inputs

import com.pulumi.azurenative.containerinstance.inputs.GpuResourceArgs.builder
import com.pulumi.azurenative.containerinstance.kotlin.enums.GpuSku
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The GPU resource.
 * @property count The count of the GPU resource.
 * @property sku The SKU of the GPU resource.
 */
public data class GpuResourceArgs(
    public val count: Output<Int>,
    public val sku: Output<Either<String, GpuSku>>,
) : ConvertibleToJava<com.pulumi.azurenative.containerinstance.inputs.GpuResourceArgs> {
    override fun toJava(): com.pulumi.azurenative.containerinstance.inputs.GpuResourceArgs =
        com.pulumi.azurenative.containerinstance.inputs.GpuResourceArgs.builder()
            .count(count.applyValue({ args0 -> args0 }))
            .sku(
                sku.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [GpuResourceArgs].
 */
@PulumiTagMarker
public class GpuResourceArgsBuilder internal constructor() {
    private var count: Output<Int>? = null

    private var sku: Output<Either<String, GpuSku>>? = null

    /**
     * @param value The count of the GPU resource.
     */
    @JvmName("exufvgttcvrorfew")
    public suspend fun count(`value`: Output<Int>) {
        this.count = value
    }

    /**
     * @param value The SKU of the GPU resource.
     */
    @JvmName("eleyjvhklnqghkga")
    public suspend fun sku(`value`: Output<Either<String, GpuSku>>) {
        this.sku = value
    }

    /**
     * @param value The count of the GPU resource.
     */
    @JvmName("axnitctmrtimywrv")
    public suspend fun count(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.count = mapped
    }

    /**
     * @param value The SKU of the GPU resource.
     */
    @JvmName("wmmdivvjymtkhjis")
    public suspend fun sku(`value`: Either<String, GpuSku>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    /**
     * @param value The SKU of the GPU resource.
     */
    @JvmName("xkcucxmlmwssqkwo")
    public fun sku(`value`: String) {
        val toBeMapped = Either.ofLeft<String, GpuSku>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    /**
     * @param value The SKU of the GPU resource.
     */
    @JvmName("berkununwvceplrh")
    public fun sku(`value`: GpuSku) {
        val toBeMapped = Either.ofRight<String, GpuSku>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    internal fun build(): GpuResourceArgs = GpuResourceArgs(
        count = count ?: throw PulumiNullFieldException("count"),
        sku = sku ?: throw PulumiNullFieldException("sku"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerinstance/kotlin/inputs/GpuResourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerinstance.kotlin.inputs

import com.pulumi.azurenative.containerinstance.inputs.GpuResourceArgs.builder
import com.pulumi.azurenative.containerinstance.kotlin.enums.GpuSku
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The GPU resource.
 * @property count The count of the GPU resource.
 * @property sku The SKU of the GPU resource.
 */
public data class GpuResourceArgs(
    public val count: Output<Int>,
    public val sku: Output<Either<String, GpuSku>>,
) : ConvertibleToJava<com.pulumi.azurenative.containerinstance.inputs.GpuResourceArgs> {
    override fun toJava(): com.pulumi.azurenative.containerinstance.inputs.GpuResourceArgs =
        com.pulumi.azurenative.containerinstance.inputs.GpuResourceArgs.builder()
            .count(count.applyValue({ args0 -> args0 }))
            .sku(
                sku.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [GpuResourceArgs].
 */
@PulumiTagMarker
public class GpuResourceArgsBuilder internal constructor() {
    private var count: Output<Int>? = null

    private var sku: Output<Either<String, GpuSku>>? = null

    /**
     * @param value The count of the GPU resource.
     */
    @JvmName("ukcekmpxxnxxpbto")
    public suspend fun count(`value`: Output<Int>) {
        this.count = value
    }

    /**
     * @param value The SKU of the GPU resource.
     */
    @JvmName("efwyodaskelhiopa")
    public suspend fun sku(`value`: Output<Either<String, GpuSku>>) {
        this.sku = value
    }

    /**
     * @param value The count of the GPU resource.
     */
    @JvmName("hrqwaeoybqxoklec")
    public suspend fun count(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.count = mapped
    }

    /**
     * @param value The SKU of the GPU resource.
     */
    @JvmName("ubylfjcvvtexnniy")
    public suspend fun sku(`value`: Either<String, GpuSku>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    /**
     * @param value The SKU of the GPU resource.
     */
    @JvmName("sgnrpjfmjdskbcmy")
    public fun sku(`value`: String) {
        val toBeMapped = Either.ofLeft<String, GpuSku>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    /**
     * @param value The SKU of the GPU resource.
     */
    @JvmName("bcqaaqrcfvowlewy")
    public fun sku(`value`: GpuSku) {
        val toBeMapped = Either.ofRight<String, GpuSku>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    internal fun build(): GpuResourceArgs = GpuResourceArgs(
        count = count ?: throw PulumiNullFieldException("count"),
        sku = sku ?: throw PulumiNullFieldException("sku"),
    )
}
